@@ -43,7 +43,7 @@ namespace aria2 {
 
 const std::string ChunkedDecoder::NAME("ChunkedDecoder");
 
-ChunkedDecoder::ChunkedDecoder():_chunkSize(0), _state(READ_SIZE) {}
+ChunkedDecoder::ChunkedDecoder():chunkSize_(0), state_(READ_SIZE) {}
 
 ChunkedDecoder::~ChunkedDecoder() {}
 
@@ -64,6 +64,27 @@ static bool readChunkSize(uint64_t& chunkSize, std::string& in)
   return true;
 }
 
+static bool readTrailer(std::string& in)
+{
+  std::string::size_type crlfPos = in.find(A2STR::CRLF);
+  if(crlfPos == std::string::npos) {
+    return false;
+  }
+  if(crlfPos == 0) {
+    return true;
+  } else {
+    if(in.size() > crlfPos+3) {
+      if(in[crlfPos+2] == '\r' && in[crlfPos+3] == '\n') {
+        return true;
+      } else {
+        throw DL_ABORT_EX("No CRLF at the end of chunk stream.");
+      }
+    } else {
+      return false;
+    }
+  }
+}
+
 static bool readData(std::string& out, uint64_t& chunkSize, std::string& in)
 {
   uint64_t readlen = std::min(chunkSize, static_cast<uint64_t>(in.size()));
@@ -84,24 +105,30 @@ static bool readData(std::string& out, uint64_t& chunkSize, std::string& in)
 
 std::string ChunkedDecoder::decode(const unsigned char* inbuf, size_t inlen)
 {
-  _buf.append(&inbuf[0], &inbuf[inlen]);
+  buf_.append(&inbuf[0], &inbuf[inlen]);
   
   std::string outbuf;
   while(1) {
-    if(_state == READ_SIZE) {
-      if(readChunkSize(_chunkSize, _buf)) {
-        if(_chunkSize == 0) {
-          _state = STREAM_END;
-          break;
+    if(state_ == READ_SIZE) {
+      if(readChunkSize(chunkSize_, buf_)) {
+        if(chunkSize_ == 0) {
+          state_ = READ_TRAILER;
         } else {
-          _state = READ_DATA;
+          state_ = READ_DATA;
         }
       } else {
         break;
       }
-    } else if(_state == READ_DATA) {
-      if(readData(outbuf, _chunkSize, _buf)) {
-        _state = READ_SIZE;
+    } else if(state_ == READ_DATA) {
+      if(readData(outbuf, chunkSize_, buf_)) {
+        state_ = READ_SIZE;
+      } else {
+        break;
+      }
+    } else if(state_ == READ_TRAILER) {
+      if(readTrailer(buf_)) {
+        state_ = STREAM_END;
+        break;
       } else {
         break;
       }
@@ -112,7 +139,7 @@ std::string ChunkedDecoder::decode(const unsigned char* inbuf, size_t inlen)
 
 bool ChunkedDecoder::finished()
 {
-  return _state == STREAM_END;
+  return state_ == STREAM_END;
 }
 
 void ChunkedDecoder::release() {}
