@@ -35,7 +35,6 @@
 #include "DHTQueryMessage.h"
 #include "DHTNode.h"
 #include "util.h"
-#include "bencode.h"
 #include "a2functional.h"
 
 namespace aria2 {
@@ -51,15 +50,15 @@ DHTQueryMessage::DHTQueryMessage(const SharedHandle<DHTNode>& localNode,
 
 DHTQueryMessage::~DHTQueryMessage() {}
 
-std::string DHTQueryMessage::getType() const
+const std::string& DHTQueryMessage::getType() const
 {
   return Q;
 }
 
-void DHTQueryMessage::fillMessage(BDE& msgDict)
+void DHTQueryMessage::fillMessage(Dict* msgDict)
 {
-  msgDict[Q] = getMessageType();
-  msgDict[A] = getArgument();
+  msgDict->put(Q, getMessageType());
+  msgDict->put(A, getArgument());
 }
 
 bool DHTQueryMessage::isReply() const
@@ -71,14 +70,14 @@ std::string DHTQueryMessage::toString() const
 {
   std::string s = strconcat
     ("dht query ", getMessageType(),
-     " TransactionID=", util::toHex(_transactionID),
-     " Remote:", _remoteNode->getIPAddress(),
-     ":", util::uitos(_remoteNode->getPort()),
-     ", id=", util::toHex(_remoteNode->getID(), DHT_ID_LENGTH),
+     " TransactionID=", util::toHex(getTransactionID()),
+     " Remote:", getRemoteNode()->getIPAddress(),
+     ":", util::uitos(getRemoteNode()->getPort()),
+     ", id=", util::toHex(getRemoteNode()->getID(), DHT_ID_LENGTH),
      ", ");
-  if(!_version.empty()) {
+  if(!getVersion().empty()) {
     s += "v=";
-    s += util::torrentPercentEncode(_version);
+    s += util::torrentPercentEncode(getVersion());
     s += ", ";
   }
   s += toStringOptional();
