@@ -43,12 +43,13 @@ FallocFileAllocationIterator::FallocFileAllocationIterator
 
 void FallocFileAllocationIterator::allocateChunk()
 {
-  if(static_cast<uint64_t>(offset_) > totalLength_) {
-    throw DL_ABORT_EX("FallocFileAllocationIterator: offset is larger than"
-                      " totalLength");
+  if(static_cast<uint64_t>(offset_) < totalLength_) {
+    stream_->allocate(offset_, totalLength_-offset_);
+    offset_ = totalLength_;
+  } else {
+    stream_->truncate(totalLength_);
+    offset_ = totalLength_;
   }
-  stream_->allocate(offset_, totalLength_-offset_);
-  offset_ = totalLength_;
 }
 
 bool FallocFileAllocationIterator::finished()
