@@ -46,13 +46,13 @@ class PeerStorage;
 
 class PeerChokeCommand : public Command {
 private:
-  DownloadEngine* e;
+  DownloadEngine* e_;
 
-  SharedHandle<PeerStorage> _peerStorage;
+  SharedHandle<PeerStorage> peerStorage_;
 
-  SharedHandle<BtRuntime> _btRuntime;
+  SharedHandle<BtRuntime> btRuntime_;
 public:
-  PeerChokeCommand(int32_t cuid,
+  PeerChokeCommand(cuid_t cuid,
                    DownloadEngine* e);
 
   virtual ~PeerChokeCommand();
