@@ -72,11 +72,14 @@
 #include "bittorrent_helper.h"
 #include "UTMetadataRequestFactory.h"
 #include "UTMetadataRequestTracker.h"
+#include "ServerStatMan.h"
+#include "FileAllocationEntry.h"
+#include "CheckIntegrityEntry.h"
 
 namespace aria2 {
 
 PeerInteractionCommand::PeerInteractionCommand
-(int32_t cuid,
+(cuid_t cuid,
  RequestGroup* requestGroup,
  const SharedHandle<Peer>& p,
  DownloadEngine* e,
@@ -87,23 +90,21 @@ PeerInteractionCommand::PeerInteractionCommand
  Seq sequence,
  const PeerConnectionHandle& passedPeerConnection)
   :PeerAbstractCommand(cuid, p, e, s),
-   _requestGroup(requestGroup),
-   _btRuntime(btRuntime),
-   _pieceStorage(pieceStorage),
-   _peerStorage(peerStorage),
-   sequence(sequence)
+   requestGroup_(requestGroup),
+   btRuntime_(btRuntime),
+   pieceStorage_(pieceStorage),
+   peerStorage_(peerStorage),
+   sequence_(sequence)
 {
   // TODO move following bunch of processing to separate method, like init()
-  if(sequence == INITIATOR_SEND_HANDSHAKE) {
+  if(sequence_ == INITIATOR_SEND_HANDSHAKE) {
     disableReadCheckSocket();
-    setWriteCheckSocket(socket);
+    setWriteCheckSocket(getSocket());
     setTimeout(getOption()->getAsInt(PREF_PEER_CONNECTION_TIMEOUT));
   }
-
-  const BDE& torrentAttrs =
-    _requestGroup->getDownloadContext()->getAttribute(bittorrent::BITTORRENT);
-
-  bool metadataGetMode = !torrentAttrs.containsKey(bittorrent::METADATA);
+  SharedHandle<TorrentAttribute> torrentAttrs =
+    bittorrent::getTorrentAttrs(requestGroup_->getDownloadContext());
+  bool metadataGetMode = torrentAttrs->metadata.empty();
 
   SharedHandle<ExtensionMessageRegistry> exMsgRegistry
     (new ExtensionMessageRegistry());
@@ -116,32 +117,32 @@ PeerInteractionCommand::PeerInteractionCommand
   }
 
   SharedHandle<DefaultExtensionMessageFactory> extensionMessageFactory
-    (new DefaultExtensionMessageFactory(peer, exMsgRegistry));
+    (new DefaultExtensionMessageFactory(getPeer(), exMsgRegistry));
   extensionMessageFactory->setPeerStorage(peerStorage);
   extensionMessageFactory->setDownloadContext
-    (_requestGroup->getDownloadContext());
+    (requestGroup_->getDownloadContext());
   extensionMessageFactory->setUTMetadataRequestTracker
     (utMetadataRequestTracker);
   // PieceStorage will be set later.
 
   SharedHandle<DefaultBtMessageFactory> factory(new DefaultBtMessageFactory());
   factory->setCuid(cuid);
-  factory->setDownloadContext(_requestGroup->getDownloadContext());
+  factory->setDownloadContext(requestGroup_->getDownloadContext());
   factory->setPieceStorage(pieceStorage);
   factory->setPeerStorage(peerStorage);
   factory->setExtensionMessageFactory(extensionMessageFactory);
-  factory->setPeer(peer);
-  factory->setLocalNode(DHTRegistry::_localNode);
-  factory->setRoutingTable(DHTRegistry::_routingTable);
-  factory->setTaskQueue(DHTRegistry::_taskQueue);
-  factory->setTaskFactory(DHTRegistry::_taskFactory);
+  factory->setPeer(getPeer());
+  factory->setLocalNode(DHTRegistry::getData().localNode);
+  factory->setRoutingTable(DHTRegistry::getData().routingTable);
+  factory->setTaskQueue(DHTRegistry::getData().taskQueue);
+  factory->setTaskFactory(DHTRegistry::getData().taskFactory);
   if(metadataGetMode) {
     factory->enableMetadataGetMode();
   }
 
   PeerConnectionHandle peerConnection;
   if(passedPeerConnection.isNull()) {
-    peerConnection.reset(new PeerConnection(cuid, socket));
+    peerConnection.reset(new PeerConnection(cuid, getSocket()));
   } else {
     peerConnection = passedPeerConnection;
   }
@@ -149,34 +150,31 @@ PeerInteractionCommand::PeerInteractionCommand
   SharedHandle<DefaultBtMessageDispatcher> dispatcher
     (new DefaultBtMessageDispatcher());
   dispatcher->setCuid(cuid);
-  dispatcher->setPeer(peer);
-  dispatcher->setDownloadContext(_requestGroup->getDownloadContext());
+  dispatcher->setPeer(getPeer());
+  dispatcher->setDownloadContext(requestGroup_->getDownloadContext());
   dispatcher->setPieceStorage(pieceStorage);
   dispatcher->setPeerStorage(peerStorage);
   dispatcher->setRequestTimeout(getOption()->getAsInt(PREF_BT_REQUEST_TIMEOUT));
   dispatcher->setBtMessageFactory(factory);
-  dispatcher->setRequestGroupMan(e->_requestGroupMan);
+  dispatcher->setRequestGroupMan(getDownloadEngine()->getRequestGroupMan());
 
   DefaultBtMessageReceiverHandle receiver(new DefaultBtMessageReceiver());
-  receiver->setCuid(cuid);
-  receiver->setPeer(peer);
-  receiver->setDownloadContext(_requestGroup->getDownloadContext());
+  receiver->setDownloadContext(requestGroup_->getDownloadContext());
   receiver->setPeerConnection(peerConnection);
   receiver->setDispatcher(dispatcher);
   receiver->setBtMessageFactory(factory);
 
   SharedHandle<DefaultBtRequestFactory> reqFactory
     (new DefaultBtRequestFactory());
-  reqFactory->setCuid(cuid);
-  reqFactory->setPeer(peer);
+  reqFactory->setPeer(getPeer());
   reqFactory->setPieceStorage(pieceStorage);
   reqFactory->setBtMessageDispatcher(dispatcher);
   reqFactory->setBtMessageFactory(factory);
 
   DefaultBtInteractiveHandle btInteractive
-    (new DefaultBtInteractive(_requestGroup->getDownloadContext(), peer));
-  btInteractive->setBtRuntime(_btRuntime);
-  btInteractive->setPieceStorage(_pieceStorage);
+    (new DefaultBtInteractive(requestGroup_->getDownloadContext(), getPeer()));
+  btInteractive->setBtRuntime(btRuntime_);
+  btInteractive->setPieceStorage(pieceStorage_);
   btInteractive->setPeerStorage(peerStorage); // Note: Not a member variable.
   btInteractive->setCuid(cuid);
   btInteractive->setBtMessageReceiver(receiver);
@@ -187,16 +185,16 @@ PeerInteractionCommand::PeerInteractionCommand
   btInteractive->setExtensionMessageRegistry(exMsgRegistry);
   btInteractive->setKeepAliveInterval
     (getOption()->getAsInt(PREF_BT_KEEP_ALIVE_INTERVAL));
-  btInteractive->setRequestGroupMan(e->_requestGroupMan);
+  btInteractive->setRequestGroupMan(getDownloadEngine()->getRequestGroupMan());
   btInteractive->setBtMessageFactory(factory);
-  if((metadataGetMode || torrentAttrs[bittorrent::PRIVATE].i() == 0) &&
-     !peer->isLocalPeer()) {
+  if((metadataGetMode || !torrentAttrs->privateTorrent) &&
+     !getPeer()->isLocalPeer()) {
     if(getOption()->getAsBool(PREF_ENABLE_PEER_EXCHANGE)) {
       btInteractive->setUTPexEnabled(true);
     }
     if(DHTSetup::initialized()) {
       btInteractive->setDHTEnabled(true);
-      btInteractive->setLocalNode(DHTRegistry::_localNode);
+      btInteractive->setLocalNode(DHTRegistry::getData().localNode);
       factory->setDHTEnabled(true);
     }
   }
@@ -206,7 +204,7 @@ PeerInteractionCommand::PeerInteractionCommand
     btInteractive->enableMetadataGetMode();
   }
 
-  this->btInteractive = btInteractive;
+  btInteractive_ = btInteractive;
 
   // reverse depends
   factory->setBtMessageDispatcher(dispatcher);
@@ -218,143 +216,142 @@ PeerInteractionCommand::PeerInteractionCommand
 
   if(metadataGetMode) {
     utMetadataRequestFactory->setDownloadContext
-      (_requestGroup->getDownloadContext());
+      (requestGroup_->getDownloadContext());
     utMetadataRequestFactory->setBtMessageDispatcher(dispatcher);
     utMetadataRequestFactory->setBtMessageFactory(factory);
-    utMetadataRequestFactory->setPeer(peer);
+    utMetadataRequestFactory->setPeer(getPeer());
     utMetadataRequestFactory->setUTMetadataRequestTracker
       (utMetadataRequestTracker);
   }
 
-  peer->allocateSessionResource
-    (_requestGroup->getDownloadContext()->getPieceLength(),
-     _requestGroup->getDownloadContext()->getTotalLength());
-  peer->setBtMessageDispatcher(dispatcher);
+  getPeer()->allocateSessionResource
+    (requestGroup_->getDownloadContext()->getPieceLength(),
+     requestGroup_->getDownloadContext()->getTotalLength());
+  getPeer()->setBtMessageDispatcher(dispatcher);
 
-  _btRuntime->increaseConnections();
-  _requestGroup->increaseNumCommand();
+  btRuntime_->increaseConnections();
+  requestGroup_->increaseNumCommand();
 }
 
 PeerInteractionCommand::~PeerInteractionCommand() {
-  if(peer->getCompletedLength() > 0) {
-    _pieceStorage->subtractPieceStats(peer->getBitfield(),
-                                      peer->getBitfieldLength());
+  if(getPeer()->getCompletedLength() > 0) {
+    pieceStorage_->subtractPieceStats(getPeer()->getBitfield(),
+                                      getPeer()->getBitfieldLength());
   }
-  peer->releaseSessionResource();
+  getPeer()->releaseSessionResource();
 
-  _requestGroup->decreaseNumCommand();
-  _btRuntime->decreaseConnections();
-  //logger->debug("CUID#%d - unregistered message factory using ID:%s",
-  //cuid, peer->getId().c_str());
+  requestGroup_->decreaseNumCommand();
+  btRuntime_->decreaseConnections();
 }
 
 bool PeerInteractionCommand::executeInternal() {
   setNoCheck(false);
-  switch(sequence) {
+  switch(sequence_) {
   case INITIATOR_SEND_HANDSHAKE:
-    if(!socket->isWritable(0)) {
+    if(!getSocket()->isWritable(0)) {
       break;
     }
     disableWriteCheckSocket();
-    setReadCheckSocket(socket);
+    setReadCheckSocket(getSocket());
     //socket->setBlockingMode();
     setTimeout(getOption()->getAsInt(PREF_BT_TIMEOUT));
-    btInteractive->initiateHandshake();
-    sequence = INITIATOR_WAIT_HANDSHAKE;
+    btInteractive_->initiateHandshake();
+    sequence_ = INITIATOR_WAIT_HANDSHAKE;
     break;
   case INITIATOR_WAIT_HANDSHAKE: {
-    if(btInteractive->countPendingMessage() > 0) {
-      btInteractive->sendPendingMessage();
-      if(btInteractive->countPendingMessage() > 0) {
+    if(btInteractive_->countPendingMessage() > 0) {
+      btInteractive_->sendPendingMessage();
+      if(btInteractive_->countPendingMessage() > 0) {
         break;
       }
     }
-    BtMessageHandle handshakeMessage = btInteractive->receiveHandshake();
+    BtMessageHandle handshakeMessage = btInteractive_->receiveHandshake();
     if(handshakeMessage.isNull()) {
       break;
     }
-    btInteractive->doPostHandshakeProcessing();
-    sequence = WIRED;
+    btInteractive_->doPostHandshakeProcessing();
+    sequence_ = WIRED;
     break;
   }
   case RECEIVER_WAIT_HANDSHAKE: {
-    BtMessageHandle handshakeMessage = btInteractive->receiveAndSendHandshake();
+    BtMessageHandle handshakeMessage =btInteractive_->receiveAndSendHandshake();
     if(handshakeMessage.isNull()) {
       break;
     }
-    btInteractive->doPostHandshakeProcessing();
-    sequence = WIRED;    
+    btInteractive_->doPostHandshakeProcessing();
+    sequence_ = WIRED;    
     break;
   }
   case WIRED:
     // See the comment for writable check below.
     disableWriteCheckSocket();
 
-    btInteractive->doInteractionProcessing();
-    if(btInteractive->countReceivedMessageInIteration() > 0) {
+    btInteractive_->doInteractionProcessing();
+    if(btInteractive_->countReceivedMessageInIteration() > 0) {
       updateKeepAlive();
     }
-    if((peer->amInterested() && !peer->peerChoking()) ||
-       btInteractive->countOutstandingRequest() ||
-       (peer->peerInterested() && !peer->amChoking())) {
+    if((getPeer()->amInterested() && !getPeer()->peerChoking()) ||
+       btInteractive_->countOutstandingRequest() ||
+       (getPeer()->peerInterested() && !getPeer()->amChoking())) {
 
       // Writable check to avoid slow seeding
-      if(btInteractive->isSendingMessageInProgress()) {
-        setWriteCheckSocket(socket);
+      if(btInteractive_->isSendingMessageInProgress()) {
+        setWriteCheckSocket(getSocket());
       }
 
-      if(e->_requestGroupMan->doesOverallDownloadSpeedExceed() ||
-         _requestGroup->doesDownloadSpeedExceed()) {
+      if(getDownloadEngine()->getRequestGroupMan()->
+         doesOverallDownloadSpeedExceed() ||
+         requestGroup_->doesDownloadSpeedExceed()) {
         disableReadCheckSocket();
         setNoCheck(true);
       } else {
-        setReadCheckSocket(socket);
+        setReadCheckSocket(getSocket());
       }
     } else {
       disableReadCheckSocket();
     }
     break;
   }
-  if(btInteractive->countPendingMessage() > 0) {
+  if(btInteractive_->countPendingMessage() > 0) {
     setNoCheck(true);
   }
-  e->commands.push_back(this);
+  getDownloadEngine()->addCommand(this);
   return false;
 }
 
 // TODO this method removed when PeerBalancerCommand is implemented
 bool PeerInteractionCommand::prepareForNextPeer(time_t wait) {
-  if(_peerStorage->isPeerAvailable() && _btRuntime->lessThanEqMinPeers()) {
-    SharedHandle<Peer> peer = _peerStorage->getUnusedPeer();
-    peer->usedBy(e->newCUID());
+  if(peerStorage_->isPeerAvailable() && btRuntime_->lessThanEqMinPeers()) {
+    SharedHandle<Peer> peer = peerStorage_->getUnusedPeer();
+    peer->usedBy(getDownloadEngine()->newCUID());
     PeerInitiateConnectionCommand* command =
       new PeerInitiateConnectionCommand
-      (peer->usedBy(), _requestGroup, peer, e, _btRuntime);
-    command->setPeerStorage(_peerStorage);
-    command->setPieceStorage(_pieceStorage);
-    e->commands.push_back(command);
+      (peer->usedBy(), requestGroup_, peer, getDownloadEngine(), btRuntime_);
+    command->setPeerStorage(peerStorage_);
+    command->setPieceStorage(pieceStorage_);
+    getDownloadEngine()->addCommand(command);
   }
   return true;
 }
 
 void PeerInteractionCommand::onAbort() {
-  btInteractive->cancelAllPiece();
-  _peerStorage->returnPeer(peer);
+  btInteractive_->cancelAllPiece();
+  peerStorage_->returnPeer(getPeer());
 }
 
 void PeerInteractionCommand::onFailure()
 {
-  _requestGroup->setHaltRequested(true);
+  requestGroup_->setHaltRequested(true);
 }
 
 bool PeerInteractionCommand::exitBeforeExecute()
 {
-  return _btRuntime->isHalt();
+  return btRuntime_->isHalt();
 }
 
 const SharedHandle<Option>& PeerInteractionCommand::getOption() const
 {
-  return _requestGroup->getOption();
+  return requestGroup_->getOption();
 }
 
 } // namespace aria2
