@@ -37,29 +37,33 @@
 #include "Exception.h"
 #include "RequestGroup.h"
 #include "DownloadContext.h"
+#include "RequestGroupMan.h"
+#include "FileAllocationEntry.h"
+#include "CheckIntegrityEntry.h"
+#include "ServerStatMan.h"
 
 namespace aria2 {
 
 RealtimeCommand::RealtimeCommand(cuid_t cuid, RequestGroup* requestGroup,
                                  DownloadEngine* e):
   Command(cuid),
-  _requestGroup(requestGroup),
-  _e(e)
+  requestGroup_(requestGroup),
+  e_(e)
 {
   setStatusRealtime();
 
-  _requestGroup->increaseNumCommand();
+  requestGroup_->increaseNumCommand();
 }
 
 RealtimeCommand::~RealtimeCommand()
 {
-  _requestGroup->decreaseNumCommand();
+  requestGroup_->decreaseNumCommand();
 }
 
 bool RealtimeCommand::execute()
 {
   setStatusRealtime();
-  _e->setNoWait(true);
+  e_->setNoWait(true);
   try {
     return executeInternal();
   } catch(Exception& e) {
