@@ -273,6 +273,9 @@ public:
   {
     return queueCheck_;
   }
+
+  // Returns currently used hosts and its use count.
+  void getUsedHosts(std::vector<std::pair<size_t, std::string> >& usedHosts);
 };
 
 typedef SharedHandle<RequestGroupMan> RequestGroupManHandle;
