@@ -44,6 +44,7 @@ class HttpResponseTest : public CppUnit::TestFixture {
   CPPUNIT_TEST(testValidateResponse_good_range);
   CPPUNIT_TEST(testValidateResponse_bad_range);
   CPPUNIT_TEST(testValidateResponse_chunked);
+  CPPUNIT_TEST(testValidateResponse_withIfModifiedSince);
   CPPUNIT_TEST(testHasRetryAfter);
   CPPUNIT_TEST(testProcessRedirect);
   CPPUNIT_TEST(testRetrieveCookie);
@@ -75,6 +76,7 @@ public:
   void testValidateResponse_good_range();
   void testValidateResponse_bad_range();
   void testValidateResponse_chunked();
+  void testValidateResponse_withIfModifiedSince();
   void testHasRetryAfter();
   void testProcessRedirect();
   void testRetrieveCookie();
@@ -137,7 +139,7 @@ void HttpResponseTest::testDeterminFilename_without_ContentDisposition()
   SharedHandle<HttpHeader> httpHeader(new HttpHeader());
   SharedHandle<HttpRequest> httpRequest(new HttpRequest());
   SharedHandle<Request> request(new Request());
-  request->setUrl("http://localhost/archives/aria2-1.0.0.tar.bz2");
+  request->setUri("http://localhost/archives/aria2-1.0.0.tar.bz2");
   httpRequest->setRequest(request);
 
   httpResponse.setHttpHeader(httpHeader);
@@ -155,7 +157,7 @@ void HttpResponseTest::testDeterminFilename_with_ContentDisposition_zero_length
   httpHeader->put("Content-Disposition", "attachment; filename=\"\"");
   SharedHandle<HttpRequest> httpRequest(new HttpRequest());
   SharedHandle<Request> request(new Request());
-  request->setUrl("http://localhost/archives/aria2-1.0.0.tar.bz2");
+  request->setUri("http://localhost/archives/aria2-1.0.0.tar.bz2");
   httpRequest->setRequest(request);
 
   httpResponse.setHttpHeader(httpHeader);
@@ -173,7 +175,7 @@ void HttpResponseTest::testDeterminFilename_with_ContentDisposition()
                   "attachment; filename=\"aria2-current.tar.bz2\"");
   SharedHandle<HttpRequest> httpRequest(new HttpRequest());
   SharedHandle<Request> request(new Request());
-  request->setUrl("http://localhost/archives/aria2-1.0.0.tar.bz2");
+  request->setUri("http://localhost/archives/aria2-1.0.0.tar.bz2");
   httpRequest->setRequest(request);
 
   httpResponse.setHttpHeader(httpHeader);
@@ -217,7 +219,7 @@ void HttpResponseTest::testIsRedirect()
 
   CPPUNIT_ASSERT(!httpResponse.isRedirect());
 
-  httpHeader->setResponseStatus("304");
+  httpHeader->setResponseStatus("301");
 
   CPPUNIT_ASSERT(httpResponse.isRedirect());  
 }
@@ -333,7 +335,7 @@ void HttpResponseTest::testValidateResponse()
   SharedHandle<HttpHeader> httpHeader(new HttpHeader());
   httpResponse.setHttpHeader(httpHeader);
 
-  httpHeader->setResponseStatus("304");
+  httpHeader->setResponseStatus("301");
 
   try {
     httpResponse.validateResponse();
@@ -362,7 +364,7 @@ void HttpResponseTest::testValidateResponse_good_range()
   SharedHandle<FileEntry> fileEntry(new FileEntry("file", 1024*1024*10, 0));
   httpRequest->setFileEntry(fileEntry);
   SharedHandle<Request> request(new Request());
-  request->setUrl("http://localhost/archives/aria2-1.0.0.tar.bz2");
+  request->setUri("http://localhost/archives/aria2-1.0.0.tar.bz2");
   httpRequest->setRequest(request);
   httpResponse.setHttpRequest(httpRequest);
   httpHeader->setResponseStatus("206");
@@ -389,7 +391,7 @@ void HttpResponseTest::testValidateResponse_bad_range()
   SharedHandle<FileEntry> fileEntry(new FileEntry("file", 1024*1024*10, 0));
   httpRequest->setFileEntry(fileEntry);
   SharedHandle<Request> request(new Request());
-  request->setUrl("http://localhost/archives/aria2-1.0.0.tar.bz2");
+  request->setUri("http://localhost/archives/aria2-1.0.0.tar.bz2");
   httpRequest->setRequest(request);
   httpResponse.setHttpRequest(httpRequest);
   httpHeader->setResponseStatus("206");
@@ -415,7 +417,7 @@ void HttpResponseTest::testValidateResponse_chunked()
   SharedHandle<FileEntry> fileEntry(new FileEntry("file", 1024*1024*10, 0));
   httpRequest->setFileEntry(fileEntry);
   SharedHandle<Request> request(new Request());
-  request->setUrl("http://localhost/archives/aria2-1.0.0.tar.bz2");
+  request->setUri("http://localhost/archives/aria2-1.0.0.tar.bz2");
   httpRequest->setRequest(request);
   httpResponse.setHttpRequest(httpRequest);
   httpHeader->setResponseStatus("206");
@@ -430,6 +432,23 @@ void HttpResponseTest::testValidateResponse_chunked()
   }
 }
 
+void HttpResponseTest::testValidateResponse_withIfModifiedSince()
+{
+  HttpResponse httpResponse;
+  SharedHandle<HttpHeader> httpHeader(new HttpHeader());
+  httpResponse.setHttpHeader(httpHeader);
+  httpHeader->setResponseStatus("304");
+  SharedHandle<HttpRequest> httpRequest(new HttpRequest());
+  httpResponse.setHttpRequest(httpRequest);
+  try {
+    httpResponse.validateResponse();
+    CPPUNIT_FAIL("exception must be thrown.");
+  } catch(Exception& e) {
+  }
+  httpRequest->setIfModifiedSinceHeader("Fri, 16 Jul 2010 12:56:59 GMT");
+  httpResponse.validateResponse();
+}
+
 void HttpResponseTest::testHasRetryAfter()
 {
   HttpResponse httpResponse;
@@ -450,7 +469,7 @@ void HttpResponseTest::testProcessRedirect()
 
   SharedHandle<HttpRequest> httpRequest(new HttpRequest());
   SharedHandle<Request> request(new Request());
-  request->setUrl("http://localhost/archives/aria2-1.0.0.tar.bz2");
+  request->setUri("http://localhost/archives/aria2-1.0.0.tar.bz2");
   httpRequest->setRequest(request);
   httpResponse.setHttpRequest(httpRequest);
   
@@ -479,7 +498,7 @@ void HttpResponseTest::testRetrieveCookie()
 
   SharedHandle<HttpRequest> httpRequest(new HttpRequest());
   SharedHandle<Request> request(new Request());
-  request->setUrl("http://www.aria2.org/archives/aria2-1.0.0.tar.bz2");
+  request->setUri("http://www.aria2.org/archives/aria2-1.0.0.tar.bz2");
   httpRequest->setRequest(request);
   SharedHandle<CookieStorage> st(new CookieStorage());
   httpRequest->setCookieStorage(st);
@@ -495,9 +514,10 @@ void HttpResponseTest::testRetrieveCookie()
 
   CPPUNIT_ASSERT_EQUAL((size_t)2, st->size());
 
-  std::deque<Cookie>::const_iterator citer = st->begin();
-  CPPUNIT_ASSERT_EQUAL(std::string("k2=v2"), (*(st->begin())).toString());
-  CPPUNIT_ASSERT_EQUAL(std::string("k3=v3"), (*(st->begin()+1)).toString());
+  std::vector<Cookie> cookies;
+  st->dumpCookie(std::back_inserter(cookies));
+  CPPUNIT_ASSERT_EQUAL(std::string("k2=v2"), cookies[0].toString());
+  CPPUNIT_ASSERT_EQUAL(std::string("k3=v3"), cookies[1].toString());
 }
 
 void HttpResponseTest::testSupportsPersistentConnection()
